pub struct Pipe {
pub colon_token: Colon,
pub name: Ident,
pub argument: Option<((Bracket, Bracket), TokelStream)>,
}Expand description
A pass of a single transformer with the provided argument.
Fields
colon_token: ColonThe preceding : token.
name: IdentThe name of the transformer that is to be used within the active context.
argument: Option<((Bracket, Bracket), TokelStream)>The argument that has been passed to the respective transformer.