pub struct Pipeline(pub Vec<Pipe>);Expand description
The :-punctuated sequence of Pipe, to form a complete pipeline for an expansion block.
Tuple Fields
0: Vec<Pipe>Trait Implementations
Sourceimpl Expand for Pipeline
impl Expand for Pipeline
Sourcetype Context = TokelStream
type Context = TokelStream
Additional context or data required to expand this specific node. Read more
Sourcefn expand_with(
self,
session: &mut Session,
body: Self::Context,
) -> Result<TokenStream, Error>
fn expand_with( self, session: &mut Session, body: Self::Context, ) -> Result<TokenStream, Error>
Expands the AST node into a fully resolved token stream using explicit context. Read more