pub struct Session(/* private fields */);Expand description
The execution context for a Tokel expansion.
This struct holds the active Registry and is responsible for evaluating
TokelStreams. By default, it is pre-loaded with Tokel’s standard built-in
transformers, but it can be customized or strictly sandboxed as needed.
Implementations